==> haskell-html-conduit-1.3.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: html-conduit
version: 1.3.1
id: html-conduit-1.3.1-CLheLmyCvXr5dyK5uuu0Et
key: html-conduit-1.3.1-CLheLmyCvXr5dyK5uuu0Et
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/xml
synopsis: Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.
category: Web, Text, Conduit
abi: deddbed40461466d007bdfbe62773557
exposed: True
exposed-modules:
    Text.HTML.DOM
hidden-modules: Text.HTML.TagStream
import-dirs: /usr/lib/ghc-8.4.3/site-local/html-conduit-1.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/html-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/html-conduit-1.3.1
hs-libraries: HShtml-conduit-1.3.1-CLheLmyCvXr5dyK5uuu0Et
depends:
    base-4.11.1.0 transformers-0.5.5.0 bytestring-0.10.8.2
    containers-0.5.11.0 text-1.2.3.0
    resourcet-1.2.1-DyrMduhw6NcBH9776LSX58
    conduit-1.3.0.3-LmObnhjlBlXKWT3aaj2Pgm
    xml-conduit-1.8.0-Doa5Pr2ZrtCIFZnFpBFDO4
    xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt
    attoparsec-0.13.2.2-4pZqFyZuvv0DMBnjRhBKkq
    conduit-extra-1.3.0-TSnscT2tHE5tCWjxVhSCl
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             resourcet-1.2.1-DyrMduhw6NcBH9776LSX58=5ef1111b0548768da5656735a567125c
             conduit-1.3.0.3-LmObnhjlBlXKWT3aaj2Pgm=535591a208ecba6a439708afbfef5621
             xml-conduit-1.8.0-Doa5Pr2ZrtCIFZnFpBFDO4=a419a2d4acf750d680b3229eccd14dce
             xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt=543959199634991899560acc46edfd26
             attoparsec-0.13.2.2-4pZqFyZuvv0DMBnjRhBKkq=07053c5359c7530f0cb8534ff020b021
             conduit-extra-1.3.0-TSnscT2tHE5tCWjxVhSCl=00724e8202a4fab50907ad34e805990c
haddock-interfaces: /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock
haddock-html: /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-html-conduit-1.3.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: html-conduit
version: 1.3.1
id: html-conduit-1.3.1-EoJYDzXx8uR1xCF1vxzfM6
key: html-conduit-1.3.1-EoJYDzXx8uR1xCF1vxzfM6
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/xml
synopsis: Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.
category: Web, Text, Conduit
abi: 450076231038258b4fb1ef799f97d663
exposed: True
exposed-modules:
    Text.HTML.DOM
hidden-modules: Text.HTML.TagStream
import-dirs: /usr/lib/ghc-8.4.3/site-local/html-conduit-1.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/html-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/html-conduit-1.3.1
hs-libraries: HShtml-conduit-1.3.1-EoJYDzXx8uR1xCF1vxzfM6
depends:
    base-4.11.1.0 transformers-0.5.5.0 bytestring-0.10.8.2
    containers-0.5.11.0 text-1.2.3.0
    resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be
    conduit-1.3.0.3-66nd3O923iS53T8SI1MATt
    xml-conduit-1.8.0-FJltbUPSWixDMnrfARxCEh
    xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt
    attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ
    conduit-extra-1.3.0-87goSKbnlY0JxObgNuqdId
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be=aed379ba96ef65280506356d2c555107
             conduit-1.3.0.3-66nd3O923iS53T8SI1MATt=d2e06181920a4035b53bbf7f067a9d71
             xml-conduit-1.8.0-FJltbUPSWixDMnrfARxCEh=6d211c383cd1f227aab8bf60237f1a38
             xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt=543959199634991899560acc46edfd26
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             conduit-extra-1.3.0-87goSKbnlY0JxObgNuqdId=15e73479198449396f6e4efa6ea25606
haddock-interfaces: /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock
haddock-html: /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
